@@ -32,7 +32,10 @@ from fetchcode.package_util import ErofsUtilsGitHubSource
 from fetchcode.package_util import GitHubSource
 from fetchcode.package_util import MiniupnpPackagesGitHubSource
 from fetchcode.package_util import OpenSSLGitHubSource
+from fetchcode.package_util import construct_cocoapods_package
+from fetchcode.package_util import get_cocoapod_tags
 from fetchcode.packagedcode_models import Package
+from fetchcode.utils import get_hashed_path
 from fetchcode.utils import get_response
 
 router = Router()
@@ -40,8 +43,8 @@ router = Router()
 
 def info(url):
     """
-    Return data according to the `url` string
-    `url` string can be purl too
+    Return package metadata for a URL or PURL.
+    Return None if there is no URL, or the URL or PURL is not supported.
     """
     if url:
         try:
@@ -83,17 +86,10 @@ def get_cargo_data_from_purl(purl):
     crate = response.get("crate") or {}
     homepage_url = crate.get("homepage")
     code_view_url = crate.get("repository")
-    yield Package(
-        homepage_url=homepage_url,
-        api_url=api_url,
-        code_view_url=code_view_url,
-        download_url=download_url,
-        **purl.to_dict(),
-    )
+
     versions = response.get("versions", [])
     for version in versions:
-        version_purl = PackageURL(
-            type=purl.type, name=name, version=version.get("num"))
+        version_purl = PackageURL(type=purl.type, name=name, version=version.get("num"))
         dl_path = version.get("dl_path")
         if dl_path:
             download_url = f"{base_url}/{dl_path}"
@@ -101,6 +97,9 @@ def get_cargo_data_from_purl(purl):
             download_url = None
         declared_license = version.get("license")
 
+        if purl.version and version_purl.version != purl.version:
+            continue
+
         yield Package(
             homepage_url=homepage_url,
             api_url=api_url,
@@ -110,6 +109,9 @@ def get_cargo_data_from_purl(purl):
             **version_purl.to_dict(),
         )
 
+        if purl.version:
+            break
+
 
 @router.route("pkg:npm/.*")
 def get_npm_data_from_purl(purl):
@@ -121,41 +123,30 @@ def get_npm_data_from_purl(purl):
     name = purl.name
     version = purl.version
     api_url = f"{base_path}/{name}"
+
     response = get_response(api_url)
     vcs_data = response.get("repository") or {}
     bugs = response.get("bugs") or {}
-
     download_url = f"{base_path}/{name}/-/{name}-{version}.tgz" if version else None
     vcs_url = vcs_data.get("url")
     bug_tracking_url = bugs.get("url")
     license = response.get("license")
     homepage_url = response.get("homepage")
 
-    yield Package(
-        homepage_url=homepage_url,
-        api_url=api_url,
-        vcs_url=vcs_url,
-        bug_tracking_url=bug_tracking_url,
-        download_url=download_url,
-        declared_license=license,
-        **purl.to_dict(),
-    )
-
     versions = response.get("versions", [])
-    tags = []
     for num in versions:
         version = versions[num]
-        version_purl = PackageURL(
-            type=purl.type, name=name, version=version.get("version")
-        )
+        version_purl = PackageURL(type=purl.type, name=name, version=version.get("version"))
         repository = version.get("repository") or {}
         bugs = response.get("bugs") or {}
         dist = version.get("dist") or {}
-        licenses = version.get("licenses") or [{}]
         vcs_url = repository.get("url")
         download_url = dist.get("tarball")
         bug_tracking_url = bugs.get("url")
-        declared_license = licenses[0].get("type")
+        declared_license = license
+
+        if purl.version and version_purl.version != purl.version:
+            continue
 
         yield Package(
             homepage_url=homepage_url,
@@ -167,6 +158,9 @@ def get_npm_data_from_purl(purl):
             **version_purl.to_dict(),
         )
 
+        if purl.version:
+            break
+
 
 @router.route("pkg:pypi/.*")
 def get_pypi_data_from_purl(purl):
@@ -175,6 +169,7 @@ def get_pypi_data_from_purl(purl):
     """
     purl = PackageURL.from_string(purl)
     name = purl.name
+
     base_path = "https://pypi.org/pypi"
     api_url = f"{base_path}/{name}/json"
     response = get_response(api_url)
@@ -185,19 +180,14 @@ def get_pypi_data_from_purl(purl):
     project_urls = info.get("project_urls") or {}
     code_view_url = get_pypi_codeview_url(project_urls)
     bug_tracking_url = get_pypi_bugtracker_url(project_urls)
-    yield Package(
-        homepage_url=homepage_url,
-        api_url=api_url,
-        bug_tracking_url=bug_tracking_url,
-        code_view_url=code_view_url,
-        declared_license=license,
-        **purl.to_dict(),
-    )
+
     for num in releases:
         version_purl = PackageURL(type=purl.type, name=name, version=num)
         release = releases.get(num) or [{}]
         release = release[0]
         download_url = release.get("url")
+        if purl.version and version_purl.version != purl.version:
+            continue
         yield Package(
             homepage_url=homepage_url,
             api_url=api_url,
@@ -208,6 +198,9 @@ def get_pypi_data_from_purl(purl):
             **version_purl.to_dict(),
         )
 
+        if purl.version:
+            break
+
 
 @router.route("pkg:github/.*")
 def get_github_data_from_purl(purl):
@@ -294,12 +287,7 @@ def get_bitbucket_data_from_purl(purl):
     bitbucket_url = "https://bitbucket.org"
     bug_tracking_url = f"{bitbucket_url}/{namespace}/{name}/issues"
     code_view_url = f"{bitbucket_url}/{namespace}/{name}"
-    yield Package(
-        api_url=api_url,
-        bug_tracking_url=bug_tracking_url,
-        code_view_url=code_view_url,
-        **purl.to_dict(),
-    )
+
     links = response.get("links") or {}
     tags_url = links.get("tags") or {}
     tags_url = tags_url.get("href")
@@ -307,15 +295,16 @@ def get_bitbucket_data_from_purl(purl):
         return []
     tags_data = get_response(tags_url)
     tags = tags_data.get("values") or {}
+
     for tag in tags:
         version = tag.get("name") or ""
-        version_purl = PackageURL(
-            type=purl.type, namespace=namespace, name=name, version=version
-        )
-        download_url = (
-            f"{base_path}/{namespace}/{name}/downloads/{name}-{version}.tar.gz"
-        )
+        version_purl = PackageURL(type=purl.type, namespace=namespace, name=name, version=version)
+        download_url = f"{base_path}/{namespace}/{name}/downloads/{name}-{version}.tar.gz"
         code_view_url = f"{bitbucket_url}/{namespace}/{name}/src/{version}"
+
+        if purl.version and version_purl.version != purl.version:
+            continue
+
         yield Package(
             api_url=api_url,
             bug_tracking_url=bug_tracking_url,
@@ -324,6 +313,9 @@ def get_bitbucket_data_from_purl(purl):
             **version_purl.to_dict(),
         )
 
+        if purl.version:
+            break
+
 
 @router.route("pkg:rubygems/.*")
 def get_rubygems_data_from_purl(purl):
@@ -332,22 +324,38 @@ def get_rubygems_data_from_purl(purl):
     """
     purl = PackageURL.from_string(purl)
     name = purl.name
-    api_url = f"https://rubygems.org/api/v1/gems/{name}.json"
-    response = get_response(api_url)
-    declared_license = response.get("licenses") or None
-    homepage_url = response.get("homepage_uri")
-    code_view_url = response.get("source_code_uri")
-    bug_tracking_url = response.get("bug_tracker_uri")
-    download_url = response.get("gem_uri")
-    yield Package(
-        homepage_url=homepage_url,
-        api_url=api_url,
-        bug_tracking_url=bug_tracking_url,
-        code_view_url=code_view_url,
-        declared_license=declared_license,
-        download_url=download_url,
-        **purl.to_dict(),
-    )
+    all_versions_url = f"https://rubygems.org/api/v1/versions/{name}.json"
+    all_versions = get_response(all_versions_url)
+
+    for vers in all_versions:
+        version_purl = PackageURL(type=purl.type, name=name, version=vers.get("number"))
+
+        if purl.version and version_purl.version != purl.version:
+            continue
+
+        number = vers.get("number")
+        version_api = f"https://rubygems.org/api/v2/rubygems/{name}/versions/{number}.json"
+        version_api_response = get_response(version_api)
+        declared_license = version_api_response.get("licenses") or None
+        homepage_url = version_api_response.get("homepage_uri")
+        code_view_url = version_api_response.get("source_code_uri")
+        bug_tracking_url = version_api_response.get("bug_tracker_uri")
+        download_url = version_api_response.get("gem_uri")
+        repository_homepage_url = version_api_response.get("project_uri")
+
+        yield Package(
+            homepage_url=homepage_url,
+            api_url=version_api,
+            bug_tracking_url=bug_tracking_url,
+            code_view_url=code_view_url,
+            declared_license=declared_license,
+            download_url=download_url,
+            repository_homepage_url=repository_homepage_url,
+            **version_purl.to_dict(),
+        )
+
+        if purl.version:
+            break
 
 
 @router.route("pkg:gnu/.*")
@@ -356,12 +364,48 @@ def get_gnu_data_from_purl(purl):
     purl = PackageURL.from_string(purl)
     source_archive_url = f"https://ftp.gnu.org/pub/gnu/{purl.name}/"
     version_regex_template = r"^({}-)(?P<version>[\w.-]*)(.tar.gz)$"
-    version_regex = re.compile(
-        version_regex_template.format(re.escape(purl.name)))
+    version_regex = re.compile(version_regex_template.format(re.escape(purl.name)))
 
-    yield from extract_packages_from_listing(
-        purl, source_archive_url, version_regex, []
-    )
+    yield from extract_packages_from_listing(purl, source_archive_url, version_regex, [])
+
+
+@router.route("pkg:cocoapods/.*")
+def get_cocoapods_data_from_purl(purl):
+    purl = PackageURL.from_string(purl)
+    name = purl.name
+    cocoapods_org_url = f"https://cocoapods.org/pods/{name}"
+    api = "https://cdn.cocoapods.org"
+    hashed_path = get_hashed_path(name)
+    hashed_path_underscore = hashed_path.replace("/", "_")
+    file_prefix = "all_pods_versions_"
+    spec = f"{api}/{file_prefix}{hashed_path_underscore}.txt"
+    data_list = get_cocoapod_tags(spec, name)
+
+    for tag in data_list:
+        version_purl = PackageURL(type=purl.type, name=name, version=tag)
+        if purl.version and version_purl.version != purl.version:
+            continue
+
+        gh_repo_owner = None
+        gh_repo_name = name
+        podspec_api_url = f"https://raw.githubusercontent.com/CocoaPods/Specs/master/Specs/{hashed_path}/{name}/{tag}/{name}.podspec.json"
+        podspec_api_response = get_response(podspec_api_url)
+        podspec_homepage = podspec_api_response.get("homepage")
+
+        if podspec_homepage.startswith("https://github.com/"):
+            podspec_homepage_remove_gh_prefix = podspec_homepage.replace("https://github.com/", "")
+            podspec_homepage_split = podspec_homepage_remove_gh_prefix.split("/")
+            gh_repo_owner = podspec_homepage_split[0]
+            gh_repo_name = podspec_homepage_split[-1]
+
+        tag_pkg = construct_cocoapods_package(
+            version_purl, name, hashed_path, cocoapods_org_url, gh_repo_owner, gh_repo_name, tag
+        )
+
+        yield tag_pkg
+
+        if purl.version:
+            break
 
 
 @dataclasses.dataclass
@@ -372,7 +416,9 @@ class DirectoryListedSource:
     is_nested: bool = dataclasses.field(
         default=False,
         metadata={
-            "description": "Flag indicating whether the archives are nested within another directory"
+            "description": (
+                "Flag indicating whether the archives are nested within another directory"
+            )
         },
     )
     source_archive_regex: re.Pattern = dataclasses.field(
@@ -410,9 +456,7 @@ class DirectoryListedSource:
 # The udhcp is no longer maintained as a standalone project.
 # It has been fully integrated into busybox.
 class UdhcpDirectoryListedSource(DirectoryListedSource):
-    source_url = (
-        "https://web.archive.org/web/20021209021312/http://udhcp.busybox.net/source/"
-    )
+    source_url = "https://web.archive.org/web/20021209021312/http://udhcp.busybox.net/source/"
 
     @classmethod
     def get_package_info(cls, package_url):
@@ -429,8 +473,7 @@ class UdhcpDirectoryListedSource(DirectoryListedSource):
 
         else:
             for version, data in UDHCP_RELEASES.items():
-                purl = PackageURL(
-                    type="generic", name="udhcp", version=version)
+                purl = PackageURL(type="generic", name="udhcp", version=version)
                 yield Package(
                     homepage_url=cls.source_url,
                     download_url=data["url"],
@@ -440,11 +483,11 @@ class UdhcpDirectoryListedSource(DirectoryListedSource):
 
 
 class IpkgDirectoryListedSource(DirectoryListedSource):
-    source_url = "https://web.archive.org/web/20090326020239/http://handhelds.org/download/packages/ipkg/"
-    is_nested = False
-    source_archive_regex = re.compile(
-        r"^(ipkg[-_])(?P<version>[\w.-]*)(_arm.ipk|.tar.gz)$"
+    source_url = (
+        "https://web.archive.org/web/20090326020239/http://handhelds.org/download/packages/ipkg/"
     )
+    is_nested = False
+    source_archive_regex = re.compile(r"^(ipkg[-_])(?P<version>[\w.-]*)(_arm.ipk|.tar.gz)$")
     ignored_files_and_dir = []
 
     @classmethod
@@ -484,8 +527,7 @@ class UtilLinuxDirectoryListedSource(DirectoryListedSource):
 class BusyBoxDirectoryListedSource(DirectoryListedSource):
     source_url = "https://www.busybox.net/downloads/"
     # Source archive ex: busybox-1.2.3.tar.bz2
-    source_archive_regex = re.compile(
-        r"^(busybox-)(?P<version>[\w.-]*)(.tar.bz2)$")
+    source_archive_regex = re.compile(r"^(busybox-)(?P<version>[\w.-]*)(.tar.bz2)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -493,8 +535,7 @@ class BusyBoxDirectoryListedSource(DirectoryListedSource):
 class UclibcDirectoryListedSource(DirectoryListedSource):
     source_url = "https://www.uclibc.org/downloads/"
     # Source archive ex: uClibc-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(uClibc-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(uClibc-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -502,8 +543,7 @@ class UclibcDirectoryListedSource(DirectoryListedSource):
 class UclibcNGDirectoryListedSource(DirectoryListedSource):
     source_url = "https://downloads.uclibc-ng.org/releases/"
     # Source archive ex: uClibc-ng-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(uClibc-ng-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(uClibc-ng-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = True
     ignored_files_and_dir = []
 
@@ -511,8 +551,7 @@ class UclibcNGDirectoryListedSource(DirectoryListedSource):
 class Bzip2DirectoryListedSource(DirectoryListedSource):
     source_url = "https://sourceware.org/pub/bzip2/"
     # Source archive ex: bzip2-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(bzip2-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(bzip2-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -520,8 +559,7 @@ class Bzip2DirectoryListedSource(DirectoryListedSource):
 class OpenSSHDirectoryListedSource(DirectoryListedSource):
     source_url = "https://cdn.openbsd.org/pub/OpenBSD/OpenSSH/"
     # Source archive ex: openssh-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(openssh-)(?P<version>[\w.-]*)(.tgz|.tar.gz)$")
+    source_archive_regex = re.compile(r"^(openssh-)(?P<version>[\w.-]*)(.tgz|.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -529,9 +567,7 @@ class OpenSSHDirectoryListedSource(DirectoryListedSource):
 class DnsmasqDirectoryListedSource(DirectoryListedSource):
     source_url = "https://thekelleys.org.uk/dnsmasq/"
     # Source archive ex: dnsmasq-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(dnsmasq-)(?P<version>[\w.-]*)(.tar.xz|.tar.gz)$"
-    )
+    source_archive_regex = re.compile(r"^(dnsmasq-)(?P<version>[\w.-]*)(.tar.xz|.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -539,8 +575,7 @@ class DnsmasqDirectoryListedSource(DirectoryListedSource):
 class EbtablesDirectoryListedSource(DirectoryListedSource):
     source_url = "https://www.netfilter.org/pub/ebtables/"
     # Source archive ex: ebtables-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(ebtables-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(ebtables-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -548,8 +583,7 @@ class EbtablesDirectoryListedSource(DirectoryListedSource):
 class HostapdDirectoryListedSource(DirectoryListedSource):
     source_url = "https://w1.fi/releases/"
     # Source archive ex: hostapd-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(hostapd-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(hostapd-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -567,8 +601,7 @@ class Iproute2DirectoryListedSource(DirectoryListedSource):
 class IptablesDirectoryListedSource(DirectoryListedSource):
     source_url = "https://www.netfilter.org/pub/iptables/"
     # Source archive ex: iptables-1.2.3.tar.bz2
-    source_archive_regex = re.compile(
-        r"^(iptables-)(?P<version>[\w.-]*)(.tar.bz2)$")
+    source_archive_regex = re.compile(r"^(iptables-)(?P<version>[\w.-]*)(.tar.bz2)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -576,8 +609,7 @@ class IptablesDirectoryListedSource(DirectoryListedSource):
 class LibnlDirectoryListedSource(DirectoryListedSource):
     source_url = "https://www.infradead.org/~tgr/libnl/files/"
     # Source archive ex: libnl-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(libnl-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(libnl-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -585,8 +617,7 @@ class LibnlDirectoryListedSource(DirectoryListedSource):
 class LighttpdDirectoryListedSource(DirectoryListedSource):
     source_url = "https://download.lighttpd.net/lighttpd/releases-1.4.x/"
     # Source archive ex: lighttpd-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(lighttpd-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(lighttpd-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -594,9 +625,7 @@ class LighttpdDirectoryListedSource(DirectoryListedSource):
 class NftablesDirectoryListedSource(DirectoryListedSource):
     source_url = "https://www.netfilter.org/pub/nftables/"
     # Source archive ex: nftables-1.2.3.tar.bz2
-    source_archive_regex = re.compile(
-        r"^(nftables-)(?P<version>[\w.-]*)(.tar.xz|.tar.bz2)$"
-    )
+    source_archive_regex = re.compile(r"^(nftables-)(?P<version>[\w.-]*)(.tar.xz|.tar.bz2)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -604,9 +633,7 @@ class NftablesDirectoryListedSource(DirectoryListedSource):
 class WpaSupplicantDirectoryListedSource(DirectoryListedSource):
     source_url = "https://w1.fi/releases/"
     # Source archive ex: wpa_supplicant-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(wpa_supplicant-)(?P<version>[\w.-]*)(.tar.gz)$"
-    )
+    source_archive_regex = re.compile(r"^(wpa_supplicant-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -614,8 +641,7 @@ class WpaSupplicantDirectoryListedSource(DirectoryListedSource):
 class SyslinuxDirectoryListedSource(DirectoryListedSource):
     source_url = "https://mirrors.edge.kernel.org/pub/linux/utils/boot/syslinux/"
     # Source archive ex: syslinux-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(syslinux-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(syslinux-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -623,8 +649,7 @@ class SyslinuxDirectoryListedSource(DirectoryListedSource):
 class SyslinuxDirectoryListedSource(DirectoryListedSource):
     source_url = "https://mirrors.edge.kernel.org/pub/linux/utils/boot/syslinux/"
     # Source archive ex: syslinux-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(syslinux-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(syslinux-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -632,9 +657,7 @@ class SyslinuxDirectoryListedSource(DirectoryListedSource):
 class ToyboxDirectoryListedSource(DirectoryListedSource):
     source_url = "http://www.landley.net/toybox/downloads/"
     # Source archive ex: toybox-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(toybox-)(?P<version>[\w.-]*)(.tar.gz|.tar.bz2)$"
-    )
+    source_archive_regex = re.compile(r"^(toybox-)(?P<version>[\w.-]*)(.tar.gz|.tar.bz2)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -642,9 +665,7 @@ class ToyboxDirectoryListedSource(DirectoryListedSource):
 class DropbearDirectoryListedSource(DirectoryListedSource):
     source_url = "https://matt.ucc.asn.au/dropbear/releases/"
     # Source archive ex: dropbear-1.2.3.tar.bz2
-    source_archive_regex = re.compile(
-        r"^(dropbear-)(?P<version>[\w.-]*)(.tar.bz2|_i386.deb)$"
-    )
+    source_archive_regex = re.compile(r"^(dropbear-)(?P<version>[\w.-]*)(.tar.bz2|_i386.deb)$")
     is_nested = False
     ignored_files_and_dir = [
         "dropbear-0.44test1.tar.bz2",
@@ -661,8 +682,7 @@ class DropbearDirectoryListedSource(DirectoryListedSource):
 class SambaDirectoryListedSource(DirectoryListedSource):
     source_url = "https://download.samba.org/pub/samba/stable/"
     # Source archive ex: samba-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(samba-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(samba-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -670,8 +690,7 @@ class SambaDirectoryListedSource(DirectoryListedSource):
 class MtdUtilsDirectoryListedSource(DirectoryListedSource):
     source_url = "https://infraroot.at/pub/mtd/"
     # Source archive ex: mtd-utils-1.2.3.tar.bz2
-    source_archive_regex = re.compile(
-        r"^(mtd-utils-)(?P<version>[\w.-]*)(.tar.bz2)$")
+    source_archive_regex = re.compile(r"^(mtd-utils-)(?P<version>[\w.-]*)(.tar.bz2)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -679,8 +698,7 @@ class MtdUtilsDirectoryListedSource(DirectoryListedSource):
 class BareboxDirectoryListedSource(DirectoryListedSource):
     source_url = "https://www.barebox.org/download/"
     # Source archive ex: barebox-1.2.3.tar.bz2
-    source_archive_regex = re.compile(
-        r"^(barebox-)(?P<version>[\w.-]*)(.tar.bz2)$")
+    source_archive_regex = re.compile(r"^(barebox-)(?P<version>[\w.-]*)(.tar.bz2)$")
     is_nested = False
     ignored_files_and_dir = []
 
@@ -688,8 +706,7 @@ class BareboxDirectoryListedSource(DirectoryListedSource):
 class LinuxDirectoryListedSource(DirectoryListedSource):
     source_url = "https://mirrors.edge.kernel.org/pub/linux/kernel/"
     # Source archive ex: linux-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(linux-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(linux-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = True
     ignored_files_and_dir = [
         "Historic/",
@@ -707,12 +724,9 @@ class LinuxDirectoryListedSource(DirectoryListedSource):
 
 
 class E2fsprogsDirectoryListedSource(DirectoryListedSource):
-    source_url = (
-        "https://mirrors.edge.kernel.org/pub/linux/kernel/people/tytso/e2fsprogs/"
-    )
+    source_url = "https://mirrors.edge.kernel.org/pub/linux/kernel/people/tytso/e2fsprogs/"
     # Source archive ex: e2fsprogs-1.2.3.tar.gz
-    source_archive_regex = re.compile(
-        r"^(e2fsprogs-)(?P<version>[\w.-]*)(.tar.gz)$")
+    source_archive_regex = re.compile(r"^(e2fsprogs-)(?P<version>[\w.-]*)(.tar.gz)$")
     is_nested = True
     ignored_files_and_dir = ["testing/"]
 
@@ -779,9 +793,7 @@ DIR_LISTED_SOURCE_BY_PACKAGE_NAME = {
 def get_htmllisting_data_from_purl(purl):
     """Generate `Package` object from the `purl` having directory listed source"""
     package_url = PackageURL.from_string(purl)
-    return DIR_LISTED_SOURCE_BY_PACKAGE_NAME[package_url.name].get_package_info(
-        package_url
-    )
+    return DIR_LISTED_SOURCE_BY_PACKAGE_NAME[package_url.name].get_package_info(package_url)
 
 
 def get_packages_from_listing(purl, source_archive_url, regex, ignored_files_and_dir):
@@ -823,9 +835,7 @@ def get_packages_from_listing(purl, source_archive_url, regex, ignored_files_and
     return packages
 
 
-def extract_packages_from_listing(
-    purl, source_archive_url, regex, ignored_files_and_dir
-):
+def extract_packages_from_listing(purl, source_archive_url, regex, ignored_files_and_dir):
     """
     Yield package data from a directory listing for the given source_archive_url.
     """
@@ -855,9 +865,7 @@ def extract_package_from_nested_listing(purl, source_url, regex, ignored_files_a
 
         directory_url = urljoin(source_url, directory.name)
 
-        for package in get_packages_from_listing(
-            purl, directory_url, regex, ignored_files_and_dir
-        ):
+        for package in get_packages_from_listing(purl, directory_url, regex, ignored_files_and_dir):
             # Don't yield all packages when a specific version is requested.
             if purl.version and package.version != purl.version:
                 continue
