@@ -1,7 +1,5 @@
-# The following comment should be removed at some point in the future.
-# mypy: disallow-untyped-defs=False
-
-from __future__ import absolute_import
+from optparse import Values
+from typing import List
 
 from fetchcode.vcs.pip._internal.cli.base_command import Command
 from fetchcode.vcs.pip._internal.cli.status_codes import SUCCESS
@@ -15,9 +13,11 @@ class HelpCommand(Command):
       %prog <command>"""
     ignore_require_venv = True
 
-    def run(self, options, args):
+    def run(self, options: Values, args: List[str]) -> int:
         from fetchcode.vcs.pip._internal.commands import (
-            commands_dict, create_command, get_similar_commands,
+            commands_dict,
+            create_command,
+            get_similar_commands,
         )
 
         try:
@@ -29,11 +29,11 @@ class HelpCommand(Command):
         if cmd_name not in commands_dict:
             guess = get_similar_commands(cmd_name)
 
-            msg = ['unknown command "{}"'.format(cmd_name)]
+            msg = [f'unknown command "{cmd_name}"']
             if guess:
-                msg.append('maybe you meant "{}"'.format(guess))
+                msg.append(f'maybe you meant "{guess}"')
 
-            raise CommandError(' - '.join(msg))
+            raise CommandError(" - ".join(msg))
 
         command = create_command(cmd_name)
         command.parser.print_help()
